@@ -2,8 +2,8 @@
 ## iters_mc         --- iterations of Gibbs sampling
 ## iters_met        --- iterations of Metropolis for each 1-dimensional sampling
 ## log_f            --- the log of the density function
-## p                --- the dim of variables sampled
-## x0               --- the initial value
+## no_var           --- the dim of variables sampled
+## ini_value        --- the initial value
 ## stepsizes_met    --- a vector of length p, with
 ##                  stepsizes_met[i] being the standard deviation of 
 ##                  Gaussian proposal for updating 'i'th parameter
@@ -12,17 +12,17 @@
 ##                  this argument is used to avoid saving the whole Markov chain
 ## ...              --- extra arguments needed to compute log_f
 
-## a matrix with of (iters + 1) * p is returned, with each row for an iteration
+## a matrix with of (iters + 1) * no_var is returned, with each row for an iteration
 
-gibbs_met <- function(log_f,p,x0,iters_mc,iters_met,stepsizes_met,
-                      iters_per.iter=1,...)
+gibbs_met <- function(log_f,no_var,ini_value,iters,iters_per.iter=1,iters_met,
+                     stepsizes_met, ...)
 {
-   if(p != length(x0))
-      stop("The number of variables in initial values does NOT match p")
-   if(!is.finite(log_f(x0,...))) 
+   if(no_var != length(ini_value))
+      stop("The number of variables in initial values does NOT match no_var")
+   if(!is.finite(log_f(ini_value,...))) 
       stop("The initial value has 0 probability") 
-   chain <- matrix(0, iters_mc + 1, p)
-   chain[1,] <- x0
+   chain <- matrix(0, iters + 1, no_var)
+   chain[1,] <- ini_value
 
    ## update only 'i_par' th parameter in 'iter' iteration
    gibbs_update_per.iter_per.par <- function(iter, i_par)
@@ -33,26 +33,28 @@ gibbs_met <- function(log_f,p,x0,iters_mc,iters_met,stepsizes_met,
        }
        ## updating parameer with index i_par with Metropolis method
        chain[iter,i_par] <<- 
-               met_gaussian(log_f_condition,iters_met,1,
-                       chain[iter,i_par],stepsizes_met[i_par])[iters_met+1]
+               met_gaussian(log_f=log_f_condition,
+                            iters=iters_met,no_var=1,
+                            ini_value=chain[iter,i_par],
+                            stepsizes_met=stepsizes_met[i_par])[iters_met+1]
    }
    ## gibbs sampling for iteration `iter' for all parameters
    gibbs_update_per.iter <- function(iter) {
         ## copy the states in 'iter-1' iteration to this iteration
         chain[iter,] <<- chain[iter-1,]
         replicate(iters_per.iter,
-                  sapply(1:p,gibbs_update_per.iter_per.par,iter=iter) )
+                  sapply(1:no_var,gibbs_update_per.iter_per.par,iter=iter) )
    }
    ## perform iters_mc gibbs sampling for all parameters
-   sapply(seq(2,iters_mc+1), gibbs_update_per.iter)
+   sapply(seq(2,iters+1), gibbs_update_per.iter)
    chain
 }
 
 ## a generic function for Metropolis sampling with Gaussian proposal
 ## iters            --- length of Markov chain
 ## log_f            --- the log of the density function
-## p                --- the number of variables being sampled
-## x0               --- the initial value
+## no_var           --- the number of variables being sampled
+## ini_value        --- the initial value
 ## stepsizes        --- the standard deviations of Gaussian proposal
 ##                  stepsizes[i] for the `i'th  variable 
 ## iters_per.iter   --- for each transition specified by `iters', 
@@ -60,20 +62,21 @@ gibbs_met <- function(log_f,p,x0,iters_mc,iters_met,stepsizes_met,
 ##                  this argument is used to avoid saving the whole Markov chain
 ## ...              --- other arguments needed to compute log_f
 
-## a matrix with of (iters + 1) * p is returned, with each row for an iteration
+## a matrix with of (iters + 1) * no_var is returned, with each row for an iteration
  
-met_gaussian <- function(log_f,iters, p, x0, stepsizes, iters_per.iter=1, ...)
+met_gaussian <- function(log_f, no_var, ini_value, 
+                         iters,iters_per.iter=1,stepsizes_met, ...)
 {   
-    if(p != length(x0))
+    if(no_var != length(ini_value))
       stop("The number of variables in initial values does NOT match p")
-    if(!is.finite(log_f(x0,...))) 
+    if(!is.finite(log_f(ini_value,...))) 
       stop("The initial value has 0 probability") 
 
     ## creating a matrix to save the Markov chain, with each row for an iteration
-    chain <- matrix(0,iters+1,p)
-    chain[1,] <- x0
+    chain <- matrix(0,iters+1,no_var)
+    chain[1,] <- ini_value
     
-    old_log_f <- log_f(x0,...)
+    old_log_f <- log_f(ini_value,...)
     ## doing one transition
     one_transition <- function(i)
     {   chain[i,] <<- chain[i-1,]
@@ -81,7 +84,7 @@ met_gaussian <- function(log_f,iters, p, x0, stepsizes, iters_per.iter=1, ...)
         repeat{
                 i_inside <- i_inside + 1
                 ## propose a point
-                x_prop <- rnorm(p) * stepsizes + chain[i,]
+                x_prop <- rnorm(no_var) * stepsizes_met + chain[i,]
                 ## decide whether to accept it
                 new_log_f <- log_f(x_prop,...)
                 if(log(runif(1)) < new_log_f - old_log_f) 
